==> operation-api-3.4.0-20141202.033341-26-sources.jar: org/gcube/data/analysis/tabulardata/operation/QueryProgress.java <==
package org.gcube.data.analysis.tabulardata.operation;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

import org.apache.commons.dbutils.DbUtils;
import org.gcube.data.analysis.tabulardata.cube.data.connection.DatabaseConnectionProvider;
import org.gcube.data.analysis.tabulardata.model.table.Table;
import org.gcube.data.analysis.tabulardata.operation.QueryThread.STATE;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class QueryProgress {

	
	private static Logger logger = LoggerFactory.getLogger(QueryProgress.class);
	
	private DatabaseConnectionProvider connectionProvider;

	private Table table;
	
	private int countExtimation;
	
	private QueryThread thread;
	
	protected QueryProgress(DatabaseConnectionProvider conn, Table table, int countExtimation, QueryThread thread) {
		super();
		this.table = table;
		this.countExtimation = countExtimation;
		this.thread = thread;
		this.connectionProvider = conn;
	}
		
	
	public float getProgress() throws SQLException, Exception{
		if (thread.getState()== STATE.FINISHED) return 1f;
		if (thread.getState()== STATE.STOPPED) throw thread.getError();
				
		Statement stmt = null;
		Connection conn = null;
		try{
			conn = connectionProvider.getConnection();
			stmt = conn.createStatement();
			ResultSet rs = stmt.executeQuery(String.format("select last_value-start_value from %s_id_seq ",table.getName()));
			rs.next();
			int seqValue = rs.getInt(1);
			float progress = (float)seqValue/(float)countExtimation;
			return progress>=1 ? 0.99f :progress;
		}catch(Throwable exception){
			throw new Exception("progress can't be calculated", exception);
		} finally {
			DbUtils.closeQuietly(stmt);
			DbUtils.closeQuietly(conn);
		}
	}
	
}

==> operation-api-3.5.0-20150216.111729-3-sources.jar: org/gcube/data/analysis/tabulardata/operation/QueryProgress.java <==
package org.gcube.data.analysis.tabulardata.operation;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

import org.apache.commons.dbutils.DbUtils;
import org.gcube.data.analysis.tabulardata.cube.data.connection.DatabaseConnectionProvider;
import org.gcube.data.analysis.tabulardata.model.table.Table;
import org.gcube.data.analysis.tabulardata.operation.QueryThread.STATE;

public class QueryProgress {

	
	//private static Logger logger = LoggerFactory.getLogger(QueryProgress.class);
	
	private DatabaseConnectionProvider connectionProvider;

	private Table table;
	
	private int countExtimation;
	
	private QueryThread thread;
	
	protected QueryProgress(DatabaseConnectionProvider conn, Table table, int countExtimation, QueryThread thread) {
		super();
		this.table = table;
		this.countExtimation = countExtimation;
		this.thread = thread;
		this.connectionProvider = conn;
	}
		
	
	public float getProgress() throws SQLException, Exception{
		if (thread.getState()== STATE.FINISHED) return 1f;
		if (thread.getState()== STATE.STOPPED) throw thread.getError();
				
		Statement stmt = null;
		Connection conn = null;
		try{
			conn = connectionProvider.getConnection();
			stmt = conn.createStatement();
			ResultSet rs = stmt.executeQuery(String.format("select last_value-start_value from %s_id_seq ",table.getName()));
			rs.next();
			int seqValue = rs.getInt(1);
			float progress = (float)seqValue/(float)countExtimation;
			return progress>=1 ? 0.99f :progress;
		}catch(Throwable exception){
			throw new Exception("progress can't be calculated", exception);
		} finally {
			DbUtils.closeQuietly(stmt);
			DbUtils.closeQuietly(conn);
		}
	}
	
}
